nagios_host 'journals.ametsoc.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'AMetSoc Home',
		'address' => 'journals.ametsoc.org',
		'contact_groups' => 'cs_escalation,ametsoc',
		'notes' => 'AMetSoc Live Site',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/AMETSOC/pages/936476697/Server+Setup+-+American+Meteorological+Society+AMetSoc'
end
nagios_host 'admin-journals.ametsoc.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'AMetSoc Admin',
		'address' => 'admin-journals.ametsoc.org',
		'contact_groups' => 'cs_escalation,ametsoc',
		'notes' => 'AMetSoc Production Management Portal',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/AMETSOC/pages/936476697/Server+Setup+-+American+Meteorological+Society+AMetSoc'
end
nagios_host 'ams-journals.ametsoc.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'AMetSoc AMS',
		'address' => 'ams-journals.ametsoc.org',
		'contact_groups' => 'cs_escalation,ametsoc',
		'notes' => 'AMetSoc Production AMS',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/AMETSOC/pages/936476697/Server+Setup+-+American+Meteorological+Society+AMetSoc'
end
#------------------------------------------------------------------------------------
# HOMEPAGE
# checks the homepage of the live AMetSoc site and checks for the string 'Meteorological'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'journals.ametsoc.org-Live Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ametsoc.org',
		'display_name' => 'Live Homepage',
		'check_command' => 'https_content_check_basic_auth!ametsoc:ametsoc2020!/!"Meteorological"!10!20!',
		'contact_groups' => 'cs_escalation,ametsoc',
		'notes' => 'AMetSoc Live Site',
		'notes_url' => 'https://journals.ametsoc.org'
end
#------------------------------------------------------------------------------------
# SEARCH
# Checks the search of the live AMetSoc site and checks for the string 'Search'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'journals.ametsoc.org-Live Search' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ametsoc.org',
		'display_name' => 'Live Search',
		'check_command' => 'https_content_check_basic_auth!ametsoc:ametsoc2020!/search!Search!10!20!',
		'contact_groups' => 'cs_escalation,ametsoc',
		'notes' => 'AMetSoc Live Site',
		'notes_url' => 'https://journals.ametsoc.org/search'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW
# checks the content view of the live AMetSoc site and checks for the string 'Meteorological'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'journals.ametsoc.org-Live content view' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ametsoc.org',
		'display_name' => 'Live content view',
		'check_command' => 'https_content_check_basic_auth!ametsoc:ametsoc2020!/jamc/issue/59/12!Meteorological!10!20!',
		'contact_groups' => 'cs_escalation,ametsoc',
		'notes' => 'AMetSoc Live Site',
		'notes_url' => 'https://journals.ametsoc.org/view/journals/2054/2054-overview.xml'
end
#------------------------------------------------------------------------------------
# LOADER
# Checks a loader login page and looks for the string 'Ametsoc PROD' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ametsoc.org-Production Loader' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'admin-journals.ametsoc.org',
		'display_name' => 'Production Loader',
		'check_command' => 'check_loader_auth!admin-journals.ametsoc.org!/login!ametsoc:ametsoc2020!"Ametsoc Production"!20!10',
		'contact_groups' => 'admins_email_only,ametsoc',
		'notes' => 'AMetSoc Live Loader',
		'notes_url' => 'https://admin-journals.ametsoc.org/login'
end
#------------------------------------------------------------------------------------
# STAGING
# Checks the staging site homepage and looks for the string 'Meteorological' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ametsoc.org-Staging Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ametsoc.org',
		'display_name' => 'Staging Homepage',
		'check_command' => 'check_staging_auth!staging-journals.ametsoc.org!ametsoc:ametsoc2020!"Meteorological"!20!10',
		'contact_groups' => 'admins_email_only,ametsoc',
		'notes' => 'AMetSoc Staging Site',
		'notes_url' => 'staging.journals.ametsoc.org'
end
#------------------------------------------------------------------------------------
# AMX
# Checks the production amx homepage and looks for the string 'AMS' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ametsoc.org-Production AMX' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ams-journals.ametsoc.org',
		'display_name' => 'Production AMX',
		'check_command' => 'check_loader_auth!ams-journals.ametsoc.org!/login!ametsoc:ametsoc2020!AMS!20!10',
		'contact_groups' => 'admins_email_only,ametsoc',
		'notes' => 'AMetSoc AMX',
		'notes_url' => 'https://ams-journals.ametsoc.org/login'
end
#------------------------------------------------------------------------------------
# FAIL OPEN
# Checks the production homepage and makes sure we're not in fail open by checking
# that the string "Provisional Account" is NOT in the page.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ametsoc.org-Live Site Fail Open' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ametsoc.org',
		'display_name' => 'Live Site Fail Open',
		'check_command' => 'http_negate_content_check_basic_auth!journals.ametsoc.org!ametsoc:ametsoc2020!"provisional account"',
		'contact_groups' => 'admins_email_only,ametsoc',
		'notes' => 'AMetSoc Live Site Failopen',
		'notes_url' => 'https://journals.ametsoc.org/'
end
